@@ -67,7 +67,12 @@ class WebClient(BaseClient):
     """
 
     def admin_analytics_getFile(
-        self, *, date: str, type: str, **kwargs
+        self,
+        *,
+        type: str,
+        date: Optional[str] = None,
+        metadata_only: Optional[bool] = None,
+        **kwargs
     ) -> SlackResponse:
         """Retrieve analytics data for a given date, presented as a compressed JSON file
 
@@ -77,7 +82,11 @@ class WebClient(BaseClient):
             type (str): The type of analytics to retrieve.
                 The options are currently limited to member.
         """
-        kwargs.update({"date": date, "type": type})
+        kwargs.update({"type": type})
+        if date is not None:
+            kwargs.update({"date": date})
+        if metadata_only is not None:
+            kwargs.update({"metadata_only": metadata_only})
         return self.api_call("admin.analytics.getFile", params=kwargs)
 
     def admin_apps_approve(
